
(defvar debian-xemacs-major-version
  (number-to-string emacs-major-version)
  "XEMacs' Major Version as string")
(defvar debian-xemacs-version
  emacs-program-version
  "XEmacs' Full Version as string")

(setq debian-info-path '("/usr/share/info"))
(when (file-directory-p "/usr/local/info")
  (setq debian-info-path (append debian-info-path '("/usr/local/info"))))
(when (file-directory-p "/usr/local/share/info")
  (setq debian-info-path (append debian-info-path '("/usr/local/share/info"))))
(setq debian-info-path (append debian-info-path
                               (list
                                (concat "/usr/share/xemacs"
                                        debian-xemacs-major-version
                                        "/xemacs-packages/info"))))
(let ((test-dir (concat "/usr/share/xemacs" debian-xemacs-major-version
                        "/mule-packages/info")))
  (when (file-directory-p test-dir)
    (setq debian-info-path (append debian-info-path (list test-dir)))))
(setq debian-info-path (append debian-info-path
                               (list (concat "/usr/share/xemacs"
                                             debian-xemacs-major-version
                                             "/site-packages/info"))))
;; don't use custom to set this var
(setq Info-directory-list debian-info-path)

(loop for entry in load-history
  if (string-match "^/home/dres/.*xemacs21/xemacs\\(21\\)?-\\([.0-9]+/\\)"
                   (car entry))
  do (setf (car entry)
           (replace-match "/usr/lib/xemacs-\\2" t nil (car entry))))


;; from bugreport #76139
(setq TeX-lisp-directory "/usr/share/xemacs21/xemacs-packages/etc/auctex/")

;;; PSGML section
(setq
 sgml-system-identifiers-are-preferred t
 sgml-local-ecat-files (quote ("ECAT" "~/sgml/ECAT"
                               "/usr/lib/sgml/ECAT"
                               "/usr/local/lib/sgml/ECAT"))
 sgml-local-catalogs (quote ("/etc/sgml/catalog"
                             "/usr/share/xemacs21/xemacs-packages/etc/psgml-dtds/CATALOG")))

(or (assoc "\\.html$" auto-mode-alist)
(setq auto-mode-alist (cons '("\\.html$" . html-mode)
                            auto-mode-alist)))
(or (assoc "\\.shtml$" auto-mode-alist)
(setq auto-mode-alist (cons '("\\.shtml$" . html-mode)
                            auto-mode-alist)))

(or (assoc "\\.htm$" auto-mode-alist)
(setq auto-mode-alist (cons '("\\.htm$" . html-mode)
                            auto-mode-alist)))
(or (assoc "\\.shtm$" auto-mode-alist)
(setq auto-mode-alist (cons '("\\.shtm$" . html-mode)
                            auto-mode-alist)))

(or (assoc "\\.xml$" auto-mode-alist)
(setq auto-mode-alist (cons '("\\.xml$" . xml-mode)
                            auto-mode-alist)))

(setq
 sgml-always-quote-attributes t
 sgml-auto-insert-required-elements t
 sgml-auto-activate-dtd t
 sgml-data-directory "/usr/lib/sgml/declaration/"
 sgml-indent-data t
 sgml-indent-step 2
 sgml-minimize-attributes nil
 sgml-omittag nil
 sgml-shortag nil
 sgml-custom-markup '(("Version1" "<![%Version1[\r]]>")
                      ("New page"  "<?NewPage>"))
 sgml-xml-declaration "/usr/lib/sgml/declaration/xml.dcl"
 sgml-live-element-indicator t
 sgml-public-map '("%S"  "/usr/lib/sgml/%S" "/usr/lib/sgml/%o/%c/%d"
                   "/usr/local/lib/sgml/%o/%c/%d")
 sgml-set-face (eq 'x  window-system)
 sgml-system-path '("/usr/lib/sgml"
                    "/usr/lib/sgml/cdtd"
                    "/usr/local/lib/sgml")
 sgml-tag-region-if-active t
 sgml-validate-command "nsgmls -e -g -s -u %s %s ")

(when (or (eq 'x  window-system)
          (eq 'gtk window-system))
  (setq
   sgml-markup-faces
   '((start-tag . font-lock-keyword-face)
     (end-tag . font-lock-keyword-face)
     (ignored . font-lock-string-face)
     (ms-start . font-lock-type-face)
     (ms-end . font-lock-type-face)
     (shortref . bold)
     (entity . font-lock-reference-face)
     (comment . font-lock-comment-face)
     (pi . font-lock-variable-name-face)
     (sgml . font-lock-function-name-face)
     (doctype . font-lock-doc-string-face))))

;;; END PSGML section

(setq module-load-path '("/usr/lib/xemacs/site-modules"))

(setq news-path "/var/spool/news")

(setq ;;'(nnmail-spool-file "/var/spool/mail/$user")
 gnuserv-program (concat exec-directory "/gnuserv"))

(when (functionp 'make-coding-system)
    (make-coding-system 'us-ascii nil))

(setq Manual-snip-subchapter nil)

(if (file-executable-p "/bin/chown")
    (setq dired-chown-program "/bin/chown")
  (setq dired-chown-program "/usr/bin/chown"))

(global-set-key [iso-left-tab] [(shift tab)])
(global-set-key [(control iso-left-tab)] [(control shift tab)])

(defun dir-and-all-good-subs (this-directory)
  "Returns list of argument and all subdirectories of argument not
starting with a '.'"
  (if (file-exists-p this-directory)
      (append (list (expand-file-name this-directory))
              (mapcar '(lambda (dir-string)
                         (concat dir-string "/"))
                      (directory-files
                       (expand-file-name this-directory)
                       t "^[^\\.]" nil 1)))
    nil))

;; make delete work correctly on console
(setq delete-key-deletes-forward t)

(setq load-path
      (append
       (dir-and-all-good-subs
        (expand-file-name "~/.xemacs/xemacs-packages"))
       (dir-and-all-good-subs
        (expand-file-name "~/.xemacs/packages"))
       (list (concat "/etc/xemacs" debian-xemacs-major-version))
       '("/etc/emacs")
       (list (concat "/usr/local/share/emacs/xemacs-" debian-xemacs-version
                     "/site-lisp"))
       '("/usr/local/share/emacs/site-lisp")
       `(,@(dir-and-all-good-subs "/usr/local/lib/xemacs/site-lisp")
           ,@(dir-and-all-good-subs
              (concat "/usr/share/xemacs/site-lisp-"
                      debian-xemacs-major-version "/"))
           ,@(dir-and-all-good-subs "/usr/share/xemacs/site-lisp/")
           ,@(dir-and-all-good-subs
              (concat "/usr/share/xemacs" debian-xemacs-major-version
                      "/site-lisp/"))
           )
       load-path
       '("/usr/share/emacs/site-lisp")))

;; make sure all the autoloads are up to date
(packages-reload-autoloads)

;; should now load from one of the /etc dirs since they are first in
;; the path now.
(load "site-start")

;;; end 00debian.el

;; Local Variables:
;; mode: emacs-lisp
;; End:
